/////////////////////////////////////////////////
// applyListColumns()
/////////////////////////////////////////////////
function applyListColumns()
{
    // if there are no entries in "displayed columns", display error to the user
    var select = document.getElementById('selOrdered');

    if (select.length == 0)
    {
        alert(errorNoDisplayedColumns);
        return;
    }

    var url    = '/mxportal/home/applyColumn.jsp' + buildURLParams();
    var iframe = document.getElementById('applyColumns');
    iframe.contentWindow.document.location.replace(url);
}

/////////////////////////////////////////////////
// closeCustomColumns()
/////////////////////////////////////////////////
function closeCustomColumns()
{
    createXeHdrWorkspace();
}

/////////////////////////////////////////////////
// buildURLParams()
/////////////////////////////////////////////////
function buildURLParams()
{
    // Loop through to concat the Node Attribute Names together
    //   format == optionValue|text*optionValue|text, etc
    var optionCount = 0;
    var attribBox   = document.getElementById('selOrdered');
    var attribCount = attribBox.length;
    var attribList  = '';

    // the columns are listed in their Column Order
    // those not present are to be hidden
    if (attribCount != 0)
    {
        attribList = attribBox.options[optionCount].value;

        for (optionCount = 1; optionCount < attribCount; optionCount++)
        {
            attribList = attribList + ',' + attribBox.options[optionCount].value;
        }
    }

    // the column that is to be the Sort Column
    var select  = document.getElementById('sortByColumn');
    var sortCol = select.value;

    // the Sort Column Direction
    var radio     = document.getElementById('sortUp');
    var sortOrder = 'ascending';

    if (radio.checked == false)
    {
        sortOrder = 'descending';
    }

    // last, check to see if the user want to apply
    // these settings to all Queries of the same type
    var checkbox = document.getElementById('applyToAll');
    var applyToAll = false;
    if (checkbox.checked == true)
    {
        applyToAll = true;
    }

    return "?cols=" + attribList + "&sortCol=" + sortCol + "&sortOrder=" + sortOrder + "&applyToAll=" + applyToAll;
}

/////////////////////////////////////////////////
// clearSelection()
/////////////////////////////////////////////////
function clearSelection(select)
{
    for (var i = 0; i < select.length; i++)
    {
        select.options[i].selected = false;
    }
}

/////////////////////////////////////////////////
// checkAvailableGray()
/////////////////////////////////////////////////
function checkAvailableGray()
{
    var select    = document.getElementById('selAvailable');
    var moveRight = document.getElementById('moveRight');

    ourButtonManager.enableButton(moveRight);

    // if nothing is selected, disable the moveRight button
    var i     = 0;
    var max   = select.length;
    var count = 0;

    // loop through all selected items in source
    for (i = 0; i < max; i++)
    {
        if (select.options[i].selected == true)
        {
            count++;
        }
    }

    if (count == 0)
    {
        ourButtonManager.disableButton(moveRight);
    }
}
/////////////////////////////////////////////////
// checkSortDirection()
/////////////////////////////////////////////////
function checkSortDirection(select)
{
    var baseColumns = document.getElementById('sortByColumnBase');
    var radio       = null;
    var index       = 0;

    for (var i = 0; i < baseColumns.length; i++)
    {
        if (baseColumns.options[i].text == select.options[select.selectedIndex].text)
        {
            index = i;
        }
    }

    if (sort[index] == true)
    {
        radio = document.getElementById('sortUp');
    }
    else
    {
        radio = document.getElementById('sortDown');
    }

    radio.click();
}
/////////////////////////////////////////////////
// checkOrderedGray()
/////////////////////////////////////////////////
function checkOrderedGray()
{
    var select   = document.getElementById('selOrdered');
    var moveLeft = document.getElementById('moveLeft');
    var moveUp   = document.getElementById('moveUp');
    var moveDown = document.getElementById('moveDown');

    ourButtonManager.enableButton(moveLeft);
    ourButtonManager.enableButton(moveUp);
    ourButtonManager.enableButton(moveDown);

    // if nothing is selected, disable the moveLeft, moveUp, and moveDown buttons
    var i     = 0;
    var max   = select.length;
    var count = 0;

    // loop through all selected items in source
    for (i = 0; i < max; i++)
    {
        if (select.options[i].selected == true)
        {
            if (i == 0)
            {
                ourButtonManager.disableButton(moveUp);
            }

            if (i == (max - 1))
            {
                ourButtonManager.disableButton(moveDown);
            }

            count++;
        }
    }

    if (count == 0)
    {
        ourButtonManager.disableButton(moveLeft);

        ourButtonManager.disableButton(moveUp);
        ourButtonManager.disableButton(moveDown);
    }
    else if (count > 1)
    {
        ourButtonManager.disableButton(moveUp);
        ourButtonManager.disableButton(moveDown);
    }
}

/////////////////////////////////////////////////
// addOptionToIndex()
/////////////////////////////////////////////////
function addOptionToIndex(select, index, optionName, optionValue)
{
    var newOption = new Option('', '');

    select.options[index]          = newOption;
    select.options[index].text     = optionName;
    select.options[index].value    = optionValue;
    select.options[index].selected = true;
}

/////////////////////////////////////////////////
// swapSelectOptions()
/////////////////////////////////////////////////
function swapSelectOptions(select, index1, index2)
{
    var tmpText = select.options[index1].text;
    var tmpVal  = select.options[index1].value;

    select.options[index1].text     = select.options[index2].text;
    select.options[index1].value    = select.options[index2].value;
    select.options[index2].text     = tmpText;
    select.options[index2].value    = tmpVal;
    select.options[index2].selected = false;
    select.options[index1].selected = true;
}

/////////////////////////////////////////////////
// selMoveUp()
/////////////////////////////////////////////////
function selMoveUp()
{
    var select = document.getElementById('selOrdered');
    var index  = select.selectedIndex;
    var max    = select.length - 1;

    if ((max < 1) || (index <= 0) || (index > max))
    {
        return;
    }

    swapSelectOptions(select, index - 1, index);
    checkOrderedGray();
    ourButtonManager.enableButtonById('applyButton');

    rebuildSortBy();
}

/////////////////////////////////////////////////
// selMoveDown()
/////////////////////////////////////////////////
function selMoveDown()
{
    var select = document.getElementById('selOrdered');
    var index  = select.selectedIndex;
    var max    = select.length - 1;

    if ((max < 1) || (index < 0) || (index >= max))
    {
        return;
    }

    swapSelectOptions(select, index + 1, index);
    checkOrderedGray();
    ourButtonManager.enableButtonById('applyButton');

    rebuildSortBy();
}

/////////////////////////////////////////////////
// selMoveSideways()
/////////////////////////////////////////////////
function selMoveSideways(source, destination)
{
    var i   = 0;
    var max = source.length;
    // loop through all selected items in source
    var firstTime = true;

    for (i = 0; i < max; i++)
    {
        if (source.options[i].selected == true)
        {
            // if first time, clear the current selection in the destination
            if (firstTime == true)
            {
                destination.options.selectedIndex = -1;
                firstTime                         = false;
            }
            // deselect current selection in destination
            // create a new destination object
            addOptionToIndex(destination, destination.length, source.options[i].text, source.options[i].value);
        }
    }
    // loop through to remove the selected items from the source
    for (i = 0; i < max; i++)
    {
        if (source.options[i].selected == true)
        {
            // remove the selected option from the source
            source.options[i] = null;
            i--; // correct for removed item
            max--;
        }
    }
    // adjust the button disability to reflect selections
    checkAvailableGray();
    checkOrderedGray();
    ourButtonManager.enableButtonById('applyButton');

    // after making the move, we have to rebuild the <option>'s in the 'sort by' <select>
    rebuildSortBy();
}

/////////////////////////////////////////////////
// rebuildSortBy()
/////////////////////////////////////////////////
function rebuildSortBy()
{
    // after making the move, we have to rebuild the <option>'s in the 'sort by' <select>
    var sortSelect  = document.getElementById('sortByColumn');
    var userColumns = document.getElementById('selOrdered');
    var baseColumns = document.getElementById('sortByColumnBase');
    // grab the current selection name so we can reselect it
    var selectedEntry = sortSelect.value;
    // set to true if we reselect this saved selection.  Otherwise
    // we will set the selection to the first item
    var setSelected   = false;

    // remove all options
    sortSelect.options.length = 0;

    var currentSelection = sortSelect.value;

    if (userColumns.length == 0)
    {
        // make it one longer
        sortSelect.options.length = 1;
        sortSelect.options[i]     = new Option("none", "--------");
        // disable this control
        sortSelect.disabled = true;
    }
    else
    {
        // enable this control
        sortSelect.disabled = false;

        // for each entry present in BASE that is also found in userColumns, add a new Option
        // this is done to maintain alphabetized list for "sort by"
        for (var i = 0; i < baseColumns.length; i++)
        {
            var option        = baseColumns.options[i];
            var optionPresent = false;

            for (var j = 0; j < userColumns.length; j++)
            {
                if (userColumns.options[j].text == option.text)
                {
                    optionPresent = true;
                }
            }

            if (optionPresent == true)
            {
                // make it one longer
                sortSelect.options.length                         = sortSelect.options.length + 1;
                sortSelect.options[sortSelect.options.length - 1] = new Option(option.text, option.value);

                if ((setSelected == false) && (selectedEntry == option.value))
                {
                    setSelected                                                = true;
                    sortSelect.options[sortSelect.options.length - 1].selected = true;
                }
            }
        }

        // if we still have not set the selection, set to the first item
        if ((setSelected == false) && (sortSelect.options.length > 0))
        {
            sortSelect.options[0].selected = true;
        }
    }
}
