//============================================================================
// "PUBLIC" FUNCTIONS
//============================================================================

// Enable an element
function enableElement(elId)
{
    setElementEnabled(elId, true);
}

// Disable an element
function disableElement(elId)
{
    setElementEnabled(elId, false);
}

function enableMxButtonElement(someId)
{
   var oButton = document.getElementById(someId);
   if (oButton != null)
   {
      oButton.disabled = false;
      oButton.className = "mx-button";
   }
}

function disableMxButtonElement(someId)
{
   var oButton = document.getElementById(someId);
   if (oButton != null)
   {
      oButton.disabled = true;
      oButton.className = "mx-button-disabled";
   }
}


// Determines whether a radio button is selected
function radioSelected(radioId)
{
    var el = document.getElementById(radioId);
    return ((el != null) && (el.checked));
}

// Determines whether a checkbox is checked
function checkboxChecked(cbId)
{
    var el = document.getElementById(cbId);
    return ((el != null) && (el.checked));
}

// Gives focus to an enabled element with the specified ID
function giveFocus(elId)
{
    var el = document.getElementById(elId);
    if ((el != null) && !el.disabled)
       el.focus()
}

// Check string to see if it is a valid character for a system name
function isValidSystemName(name)
{
    if ((name == null) || (name == ""))
        return false;

    var retVal = true;
    for (var x=0; x<name.length; x++)
    {
        if (!isValidSystemNameChar(name.charCodeAt(x)))
        {
            retVal = false;
            break;
        }
    }
    return retVal;
}

// Check character to see if it is a valid character for a system name
// useful for keypress event handling
function isValidSystemNameChar(charCode)
{
    if (((charCode >= 48) && (charCode <= 57))  ||  // 0-9
        ((charCode >= 65) && (charCode <= 90))  ||  // A-Z
        ((charCode >= 97) && (charCode <= 122)) ||  // a-z
         (charCode == 126) ||                       // ~
         (charCode == 45) ||                        // -
         (charCode == 95) ||                        // _
         (charCode == 46) ||                        // .
         (charCode == 39) )                         // '
    {
        return true;
    }
    else
    {
        return false;
    }
}

// Check string to see if it is a valid character for a search string
function isValidSearchString(name)
{
    if ((name == null) || (name == ""))
        return false;

    var retVal = true;
    for (var x=0; x<name.length; x++)
    {
        if (!isValidSearchChar(name.charCodeAt(x)))
        {
            retVal = false;
            break;
        }
    }
    return retVal;
}

// Check character to see if it is a valid character for a search string
// Just like MxNodeName check except it allows spaces
// useful for keypress event handling
function isValidSearchChar(charCode)
{
    if (((charCode >= 48) && (charCode <= 57))  ||  // 0-9
        ((charCode >= 65) && (charCode <= 90))  ||  // A-Z
        ((charCode >= 97) && (charCode <= 122)) ||  // a-z
         (charCode == 126) ||                       // ~
         (charCode == 45) ||                        // -
         (charCode == 95) ||                        // _
         (charCode == 46) ||                        // .
         (charCode == 32) ||                        // space
         (charCode == 39) ||                        // '
         (charCode == 47) ||                        // /
         (charCode >= 128 ))                        // or characters in other locales
    {
        return true;
    }
    else
    {
        return false;
    }
}

// Check string to see if it is a valid character for a list name
// Matches valid characters for InvalidCharCheck class
function isValidListName(name)
{
    if ((name == null) || (name == ""))
        return false;

    var retVal = true;
    for (var x=0; x<name.length; x++)
    {
        if (!isValidListNameChar(name.charCodeAt(x)))
        {
            retVal = false;
            break;
        }
    }
    return retVal;
}

// Check character to see if it is a valid character for a list name
// useful for keypress event handling
function isValidListNameChar(charCode)
{
    if (((charCode >= 48) && (charCode <= 57))  ||  // 0-9
        ((charCode >= 65) && (charCode <= 90))  ||  // A-Z
        ((charCode >= 97) && (charCode <= 122)) ||  // a-z
         (charCode == 46) ||                        // .
         (charCode == 32) ||                        // space
         (charCode == 95) ||                        // _
         (charCode == 45) ||                        // -
         (charCode == 44) ||                        // ,
         (charCode >= 128 ))                        // or characters in other locales
    {
        return true;
    }
    else
    {
        return false;
    }
}



// Check string to see if it contains characters valid for an IP Address
function isValidIPAddress(ipAddress)
{
    if ((ipAddress == null) || (ipAddress == ""))
        return false;

    var retVal = true;
    for (var x=0; x<ipAddress.length; x++)
    {
        if (!isValidIpAddressChar(ipAddress.charCodeAt(x)))
        {
            retVal = false;
            break;
        }
    }
    return retVal;
}

// Check character to see if it is a valid character for an IP Address
function isValidIpAddressChar(charCode)
{
    if (((charCode >= 48) && (charCode <= 57))  ||  // 0-9
         (charCode == 46))                          // .
    {
        return true;
    }
    else
    {
        return false;
    }
}

//============================================================================
// "PRIVATE" FUNCTIONS
//============================================================================

// Enable or disable an element
function setElementEnabled(elId, enableFlag)
{
    if (elId != null)
    {
        var el = document.getElementById(elId);
        if (el != null)
        {
            el.disabled = !enableFlag;
        }
    }
}

